library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

entity dp_aux_mon_v1_0 is
	generic (
		-- Users to add parameters here
		C_TXEN_POLARITY	: integer range 0 to 1	:= 0;
		C_HPD_POLARITY	: integer range 0 to 1	:= 1;
		
		-- User parameters ends
		-- Do not modify the parameters beyond this line


		-- Parameters of Axi Master Bus Interface M0_AXIS
		C_M0_AXIS_TDATA_WIDTH	: integer	:= 8
	);
	port (
		-- Users to add ports here
        dpaux_rx	: in std_logic := '1';
        dpaux_tx	: in std_logic := '1';
        dpaux_txen	: in std_logic := '0';
        dpaux_hpd	: in std_logic := '0';

        interrupt   : out std_logic; -- not implemented
        
        
        dbg_bitvalid: out std_logic;

		-- User ports ends
		-- Do not modify the ports beyond this line


		-- Ports of Axi Master Bus Interface M0_AXIS
		m0_axis_aclk	: in std_logic;
		m0_axis_aresetn	: in std_logic;
		m0_axis_tvalid	: out std_logic;
		m0_axis_tdata	: out std_logic_vector(C_M0_AXIS_TDATA_WIDTH-1 downto 0);
		m0_axis_tdest	: out std_logic_vector(0 downto 0);
		m0_axis_tlast	: out std_logic;
		m0_axis_tuser	: out std_logic_vector(0 downto 0)
		--;m0_axis_tready	: in std_logic
	);
end dp_aux_mon_v1_0;

architecture arch_imp of dp_aux_mon_v1_0 is


signal serdes_reset: std_logic;

signal txen_change: std_logic;
signal txen_sr: std_logic_vector(7 downto 0);

signal rx_tx: std_logic;

begin
    interrupt <= '0';

    m0_axis_tlast <= '0';
    m0_axis_tuser(0) <= dpaux_txen;
    m0_axis_tdest(0) <= dpaux_txen;

    -- select rx or txt path    
    rx_tx <= dpaux_tx when txen_sr(7) = '0' else dpaux_rx;

clk_proc: process(m0_axis_aclk)
	begin
		if rising_edge(m0_axis_aclk) then
		    txen_sr <= txen_sr(6 downto 0) & dpaux_txen;
		    txen_change <= txen_sr(7) xor txen_sr(0);
		end if;
	end process;

    serdes_reset <= txen_change or not m0_axis_aresetn;



i_channel: entity work.aux_serdes port map ( 
		   clk            => m0_axis_aclk,
		   reset          => serdes_reset,
		   --debug_pmod  => debug_pmod_i, 
		   ------------------------------
           dp_rx          => rx_tx,
           dbg_bitvalid   => dbg_bitvalid,
		   ------------------------------
           rx_data          => m0_axis_tdata,
           rx_valid         => m0_axis_tvalid
    );





end arch_imp;
